pm4py.algo.analysis package
===========================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pm4py.algo.analysis.extended_marking_equation
   pm4py.algo.analysis.marking_equation
   pm4py.algo.analysis.woflan
   pm4py.algo.analysis.workflow_net

Module contents
---------------

.. automodule:: pm4py.algo.analysis
   :members:
   :undoc-members:
   :show-inheritance:
